package com.ruoyi.system.service.impl.projectV2;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.projectV2.*;
import com.ruoyi.system.mapper.projectV2.ZsyzFjMapper;
import com.ruoyi.system.mapper.projectV2.ZsyzKgxxMapper;
import com.ruoyi.system.mapper.projectV2.ZsyzLcjlMapper;
import com.ruoyi.system.mapper.projectV2.ZsyzSbbzbMapper;
import com.ruoyi.system.service.projectV2.IZsyzKgxxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

import static com.ruoyi.common.constant.CommonConstants.*;

/**
 * 招商引资_开工信息Service业务层处理
 * 
 * @author boman
 * @date 2023-02-22
 */
@Service
public class ZsyzKgxxServiceImpl implements IZsyzKgxxService
{
    @Autowired
    private ZsyzKgxxMapper zsyzKgxxMapper;

    @Autowired
    private ZsyzFjMapper zsyzFjMapper;

    @Autowired
    private ZsyzSbbzbMapper zsyzSbbzbMapper;

    @Autowired
    private ZsyzLcjlMapper zsyzLcjlMapper;
    /**
     * 查询招商引资_开工信息
     * 
     * @param id 招商引资_开工信息ID
     * @return 招商引资_开工信息
     */
    @Override
    @Transactional
    public ZsyzKgxx selectZsyzKgxxById(Long id)
    {
        ZsyzKgxx zsyzKgxx = zsyzKgxxMapper.selectZsyzKgxxById(id);
        if (zsyzKgxx != null){
            ZsyzFj zsyzFj = new ZsyzFj();
            zsyzFj.setSourceId(id);
            List<ZsyzFj> zsyzFjList = zsyzFjMapper.selectZsyzFjList(zsyzFj);
            if (zsyzFjList != null && zsyzFjList.size() > 0){
                zsyzKgxx.setZsyzFjList(zsyzFjList);
            }
        }
        return zsyzKgxx;
    }

    /**
     * 查询招商引资_开工信息列表
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 招商引资_开工信息
     */
    @Override
    public List<ZsyzKgxx> selectZsyzKgxxList(ZsyzKgxx zsyzKgxx)
    {
        return zsyzKgxxMapper.selectZsyzKgxxList(zsyzKgxx);
    }

    /**
     * 新增招商引资_开工信息
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 结果
     */
    @Override
    @Transactional
    public int insertZsyzKgxx(ZsyzKgxx zsyzKgxx)
    {
        zsyzKgxx.setCreateTime(DateUtils.getNowDate());
        int count = zsyzKgxxMapper.insertZsyzKgxx(zsyzKgxx);
        ZsyzSbbzb zsyzSbbzb = new ZsyzSbbzb();
        zsyzSbbzb.setId(zsyzKgxx.getXmId());
        zsyzSbbzb.setProgress(EIG);
        zsyzSbbzbMapper.updateZsyzSbbzbProgress(zsyzSbbzb);
        //保存附件信息
        List<ZsyzFj> zsyzFjList = zsyzKgxx.getZsyzFjList();
        if (zsyzFjList != null){
            for (ZsyzFj zsyzFj : zsyzFjList) {
                zsyzFj.setSourceId(zsyzKgxx.getId());
                zsyzFj.setType("3");
                zsyzFj.setXmId(zsyzKgxx.getXmId());
                zsyzFj.setXmbh(zsyzKgxx.getXmbh());
                zsyzFjMapper.insertZsyzFj(zsyzFj);
            }
        }
        //插入流程记录表
        SysDept dept = SecurityUtils.getLoginUser().getUser().getDept();
        ZsyzLcjl zsyzLcjl = new ZsyzLcjl();
        zsyzLcjl.setXmId(zsyzSbbzb.getId());
        zsyzLcjl.setXmmc(zsyzKgxx.getXmmc());
        zsyzLcjl.setXmbh(zsyzKgxx.getXmbh());
        zsyzLcjl.setDeptId(dept.getDeptId());
        String deptName = dept.getDeptName();
        zsyzLcjl.setDeptName(deptName);
        zsyzLcjl.setProgress(EIG);
        zsyzLcjlMapper.insertZsyzLcjl(zsyzLcjl);
        return count;
    }

    /**
     * 修改招商引资_开工信息
     * 
     * @param zsyzKgxx 招商引资_开工信息
     * @return 结果
     */
    @Override
    @Transactional
    public int updateZsyzKgxx(ZsyzKgxx zsyzKgxx)
    {

        zsyzKgxx.setUpdateTime(DateUtils.getNowDate());
        int count = zsyzKgxxMapper.updateZsyzKgxx(zsyzKgxx);
        ZsyzSbbzb zsyzSbbzb = new ZsyzSbbzb();
        zsyzSbbzb.setId(zsyzKgxx.getXmId());
        ZsyzSbbzb zsyzSbbzbOld = zsyzSbbzbMapper.selectZsyzSbbzbById(zsyzKgxx.getXmId());
        if (zsyzSbbzbOld != null && zsyzSbbzbOld.getProgress().equals(SEV)){
            zsyzSbbzb.setProgress(EIG);
            zsyzSbbzbMapper.updateZsyzSbbzbProgress(zsyzSbbzb);
        }
        //修改附件
        if(zsyzKgxx.getZsyzFjList()!=null && zsyzKgxx.getZsyzFjList().size()>0){
            //先删除相关附件
            zsyzFjMapper.deleteZsyzFjBySourceId(zsyzKgxx.getId());
            //再将文件新增进数据库
            List<ZsyzFj> zsyzFjList = zsyzKgxx.getZsyzFjList();
            for (ZsyzFj zsyzFj : zsyzFjList) {
                zsyzFj.setSourceId(zsyzKgxx.getId());
                zsyzFj.setType("3");
                zsyzFj.setXmId(zsyzKgxx.getXmId());
                zsyzFj.setXmbh(zsyzKgxx.getXmbh());
                zsyzFjMapper.insertZsyzFj(zsyzFj);
            }
        }
        return count;
    }

    /**
     * 批量删除招商引资_开工信息
     * 
     * @param ids 需要删除的招商引资_开工信息ID
     * @return 结果
     */
    @Override
    public int deleteZsyzKgxxByIds(Long[] ids)
    {
        return zsyzKgxxMapper.deleteZsyzKgxxByIds(ids);
    }

    /**
     * 删除招商引资_开工信息信息
     * 
     * @param id 招商引资_开工信息ID
     * @return 结果
     */
    @Override
    public int deleteZsyzKgxxById(Long id)
    {
        return zsyzKgxxMapper.deleteZsyzKgxxById(id);
    }
}
